@@ -2368,7 +2368,7 @@ qqnorm.lme <-
           ltext(x[ids], y[ids], idLabels[subscripts][ids],
                 cex = dots$cex, adj = dots$adj)
       }
-      if (!is.null(abl)) panel.abline(abl, ...)
+      if (!is.null(abl)) { if (length(abl) == 2) panel.abline(a = abl, ...) else panel.abline(h = abl, ...) }
     }), args)
   }
   if(type == "reff" && !std) {
